@@ -1,4 +1,4 @@
-//@line 36 "/usr/obj/ports/firefox3-3.0.1p3/mozilla/browser/base/content/pageinfo/permissions.js"
+//@line 36 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/pageinfo/permissions.js"
 const ALLOW = nsIPermissionManager.ALLOW_ACTION;   // 1
 const BLOCK = nsIPermissionManager.DENY_ACTION;    // 2
 const SESSION = nsICookiePermission.ACCESS_SESSION;// 8
@@ -32,6 +32,10 @@ var gPermObj = {
     if (gPrefs.getBoolPref("xpinstall.whitelist.required"))
       return BLOCK;
     return ALLOW;
+  },
+  geo: function getGeoDefaultPermissions()
+  {
+      return BLOCK;
   }
 };
 
