@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/advanced.js"
+//@line 39 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/advanced.js"
 
 // Load DownloadUtils module for convertByteUnits
 Components.utils.import("resource://gre/modules/DownloadUtils.jsm");
@@ -24,9 +24,7 @@ var gAdvancedPane = {
       advancedPrefs.selectedIndex = preference.value;
     }
 
-    this.updateAppUpdateItems();
-    this.updateAutoItems();
-    this.updateModeItems();
+//@line 69 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/advanced.js"
     this.updateOfflineApps();
   },
 
@@ -126,7 +124,7 @@ var gAdvancedPane = {
   readCacheSize: function ()
   {
     var preference = document.getElementById("browser.cache.disk.capacity");
-    return preference.value / 1000;
+    return preference.value / 1024;
   },
 
   /**
@@ -137,7 +135,7 @@ var gAdvancedPane = {
   {
     var cacheSize = document.getElementById("cacheSize");
     var intValue = parseInt(cacheSize.value, 10);
-    return isNaN(intValue) ? 0 : intValue * 1000;
+    return isNaN(intValue) ? 0 : intValue * 1024;
   },
 
   /**
@@ -177,15 +175,24 @@ var gAdvancedPane = {
   },
 
   // XXX: duplicated in browser.js
-  _getOfflineAppUsage: function (host)
+  _getOfflineAppUsage: function (host, groups)
   {
-    var cacheService = Components.classes["@mozilla.org/network/cache-service;1"].
-                       getService(Components.interfaces.nsICacheService);
-    var cacheSession = cacheService.createSession("HTTP-offline",
-                                                  Components.interfaces.nsICache.STORE_OFFLINE,
-                                                  true).
-                       QueryInterface(Components.interfaces.nsIOfflineCacheSession);
-    var usage = cacheSession.getDomainUsage(host);
+    var cacheService = Components.classes["@mozilla.org/network/application-cache-service;1"].
+                       getService(Components.interfaces.nsIApplicationCacheService);
+    if (!groups) {
+      groups = cacheService.getGroups({});
+    }
+    var ios = Components.classes["@mozilla.org/network/io-service;1"].
+              getService(Components.interfaces.nsIIOService);
+
+    var usage = 0;
+    for (var i = 0; i < groups.length; i++) {
+      var uri = ios.newURI(groups[i], null, null);
+      if (uri.asciiHost == host) {
+        var cache = cacheService.getActiveCache(groups[i]);
+        usage += cache.usage;
+      }
+    }
 
     var storageManager = Components.classes["@mozilla.org/dom/storagemanager;1"].
                          getService(Components.interfaces.nsIDOMStorageManager);
@@ -207,6 +214,10 @@ var gAdvancedPane = {
       list.removeChild(list.firstChild);
     }
 
+    var cacheService = Components.classes["@mozilla.org/network/application-cache-service;1"].
+                       getService(Components.interfaces.nsIApplicationCacheService);
+    var groups = cacheService.getGroups({});
+
     var bundle = document.getElementById("bundlePreferences");
 
     var enumerator = pm.enumerator;
@@ -220,7 +231,7 @@ var gAdvancedPane = {
         row.className = "offlineapp";
         row.setAttribute("host", perm.host);
         var converted = DownloadUtils.
-                        convertByteUnits(this._getOfflineAppUsage(perm.host));
+                        convertByteUnits(this._getOfflineAppUsage(perm.host, groups));
         row.setAttribute("usage",
                          bundle.getFormattedString("offlineAppUsage",
                                                    converted));
@@ -261,14 +272,18 @@ var gAdvancedPane = {
       return;
 
     // clear offline cache entries
-    var cacheService = Components.classes["@mozilla.org/network/cache-service;1"]
-                       .getService(Components.interfaces.nsICacheService);
-    var cacheSession = cacheService.createSession("HTTP-offline",
-                                                  Components.interfaces.nsICache.STORE_OFFLINE,
-                                                  true)
-                       .QueryInterface(Components.interfaces.nsIOfflineCacheSession);
-    cacheSession.clearKeysOwnedByDomain(host);
-    cacheSession.evictUnownedEntries();
+    var cacheService = Components.classes["@mozilla.org/network/application-cache-service;1"].
+                       getService(Components.interfaces.nsIApplicationCacheService);
+    var ios = Components.classes["@mozilla.org/network/io-service;1"].
+              getService(Components.interfaces.nsIIOService);
+    var groups = cacheService.getGroups({});
+    for (var i = 0; i < groups.length; i++) {
+        var uri = ios.newURI(groups[i], null, null);
+        if (uri.asciiHost == host) {
+            var cache = cacheService.getActiveCache(groups[i]);
+            cache.discard();
+        }
+    }
 
     // send out an offline-app-removed signal.  The nsDOMStorage
     // service will clear DOM storage for this host.
@@ -343,51 +358,7 @@ var gAdvancedPane = {
    *             iii 0/1/2   t         true   
    * 
    */
-  updateAppUpdateItems: function () 
-  {
-    var aus = 
-        Components.classes["@mozilla.org/updates/update-service;1"].
-        getService(Components.interfaces.nsIApplicationUpdateService);
-
-    var enabledPref = document.getElementById("app.update.enabled");
-    var enableAppUpdate = document.getElementById("enableAppUpdate");
-
-    enableAppUpdate.disabled = !aus.canUpdate || enabledPref.locked;
-  },
-
-  /**
-   * Enables/disables UI for "when updates are found" based on the values,
-   * and "locked" states of associated preferences.
-   */
-  updateAutoItems: function () 
-  {
-    var enabledPref = document.getElementById("app.update.enabled");
-    var autoPref = document.getElementById("app.update.auto");
-    
-    var updateModeLabel = document.getElementById("updateModeLabel");
-    var updateMode = document.getElementById("updateMode");
-    
-    var disable = enabledPref.locked || !enabledPref.value ||
-                  autoPref.locked;
-    updateModeLabel.disabled = updateMode.disabled = disable;
-  },
-
-  /**
-   * Enables/disables the "warn if incompatible extensions/themes exist" UI
-   * based on the values and "locked" states of various preferences.
-   */
-  updateModeItems: function () 
-  {
-    var enabledPref = document.getElementById("app.update.enabled");
-    var autoPref = document.getElementById("app.update.auto");
-    var modePref = document.getElementById("app.update.mode");
-    
-    var warnIncompatible = document.getElementById("warnIncompatible");
-    
-    var disable = enabledPref.locked || !enabledPref.value || autoPref.locked ||
-                  !autoPref.value || modePref.locked;
-    warnIncompatible.disabled = disable;
-  },
+//@line 500 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/advanced.js"
 
   /**
    * The Extensions checkbox and button are disabled only if the enable Addon
@@ -400,57 +371,6 @@ var gAdvancedPane = {
 
     enableAddonUpdate.disabled = enabledPref.locked;
   },  
-
-  /**
-   * Stores the value of the app.update.mode preference, which is a tristate
-   * integer preference.  We store the value here so that we can properly
-   * restore the preference value if the UI reflecting the preference value
-   * is in a state which can represent either of two integer values (as
-   * opposed to only one possible value in the other UI state).
-   */
-  _modePreference: -1,
-
-  /**
-   * Reads the app.update.mode preference and converts its value into a
-   * true/false value for use in determining whether the "Warn me if this will
-   * disable extensions or themes" checkbox is checked.  We also save the value
-   * of the preference so that the preference value can be properly restored if
-   * the user's preferences cannot adequately be expressed by a single checkbox.
-   *
-   * app.update.modee         Checkbox State    Meaning
-   * 0                        Unchecked         Do not warn
-   * 1                        Checked           Warn if there are incompatibilities
-   * 2                        Checked           Warn if there are incompatibilities,
-   *                                            or the update is major.
-   */
-  readAddonWarn: function ()
-  {
-    var preference = document.getElementById("app.update.mode");
-    var doNotWarn = preference.value != 0;
-    gAdvancedPane._modePreference = doNotWarn ? preference.value : 1;
-    return doNotWarn;
-  },
-
-  /**
-   * Converts the state of the "Warn me if this will disable extensions or
-   * themes" checkbox into the integer preference which represents it,
-   * returning that value.
-   */
-  writeAddonWarn: function ()
-  {
-    var warnIncompatible = document.getElementById("warnIncompatible");
-    return !warnIncompatible.checked ? 0 : gAdvancedPane._modePreference;
-  },
-
-  /**
-   * Displays the history of installed updates.
-   */
-  showUpdates: function ()
-  {
-    var prompter = Components.classes["@mozilla.org/updates/update-prompt;1"]
-                             .createInstance(Components.interfaces.nsIUpdatePrompt);
-    prompter.showUpdateHistory(window);
-  },
   
   // ENCRYPTION TAB
 
@@ -485,7 +405,7 @@ var gAdvancedPane = {
    */
   showCRLs: function ()
   {
-    document.documentElement.openWindow("Mozilla:CRLManager", 
+    document.documentElement.openWindow("mozilla:crlmanager", 
                                         "chrome://pippki/content/crlManager.xul",
                                         "", null);
   },
@@ -508,7 +428,7 @@ var gAdvancedPane = {
                                         "chrome://pippki/content/device_manager.xul",
                                         "", null);
   }
-//@line 549 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/advanced.js"
+//@line 570 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/advanced.js"
   ,
 
   // SYSTEM DEFAULTS
@@ -554,5 +474,5 @@ var gAdvancedPane = {
       psvc.alert(window, promptTitle, promptMessage);
     }
   }
-//@line 595 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/advanced.js"
+//@line 616 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/advanced.js"
 };
