@@ -1,18 +1,18 @@
 /*
-//@line 44 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 44 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
  */
 
 //****************************************************************************//
 // Constants & Enumeration Values
 
 /*
-//@line 51 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 51 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
 */
 var Cc = Components.classes;
 var Ci = Components.interfaces;
 var Cr = Components.results;
 /*
-//@line 57 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 57 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
 */
 
 const TYPE_MAYBE_FEED = "application/vnd.mozilla.maybe.feed";
@@ -70,7 +70,13 @@ const PREF_AUDIO_FEED_SELECTED_READER = "browser.audioFeeds.handler.default";
 // identifying the "use plugin" action, so we use this constant instead.
 const kActionUsePlugin = 5;
 
-const ICON_URL_APP      = "chrome://browser/skin/preferences/application.png";
+/*
+//@line 116 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
+*/
+const ICON_URL_APP      = "moz-icon://dummy.exe?size=16";
+/*
+//@line 124 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
+*/
 
 // For CSS. Can be one of "ask", "save", "plugin" or "feed". If absent, the icon URL
 // was set by us to a custom handler icon and CSS should not try to override it.
@@ -81,7 +87,7 @@ const APP_ICON_ATTR_NAME = "appHandlerIcon";
 
 function getDisplayNameForFile(aFile) {
 /*
-//@line 149 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 159 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
 */
 
   return Cc["@mozilla.org/network/io-service;1"].
@@ -473,10 +479,9 @@ FeedHandlerInfo.prototype = {
     getService(Ci.nsIWebContentConverterService),
 
   _shellSvc:
-//@line 541 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
-    Cc["@mozilla.org/browser/shell-service;1"].
-    getService(Ci.nsIShellService),
-//@line 546 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 551 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
+    getShellService(),
+//@line 555 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
 
 
   //**************************************************************************//
@@ -599,14 +604,14 @@ FeedHandlerInfo.prototype = {
       return this.__defaultApplicationHandler;
 
     var defaultFeedReader = null;
-//@line 669 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 678 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
     try {
       defaultFeedReader = this._shellSvc.defaultFeedReader;
     }
     catch(ex) {
-      // no default reader
+      // no default reader or _shellSvc is null
     }
-//@line 676 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 685 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
 
     if (defaultFeedReader) {
       let handlerApp = Cc["@mozilla.org/uriloader/local-handler-app;1"].
@@ -625,15 +630,15 @@ FeedHandlerInfo.prototype = {
   },
 
   get hasDefaultHandler() {
-//@line 695 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 704 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
     try {
       if (this._shellSvc.defaultFeedReader)
         return true;
     }
     catch(ex) {
-      // no default reader
+      // no default reader or _shellSvc is null
     }
-//@line 703 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 712 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
 
     return false;
   },
@@ -917,6 +922,10 @@ var gApplicationsPane = {
       self._rebuildVisibleTypes();
       self._sortVisibleTypes();
       self._rebuildView();
+
+      // Notify observers that the UI is now ready
+      Cc["@mozilla.org/observer-service;1"].getService(Ci.nsIObserverService).
+      notifyObservers(window, "app-handler-pane-loaded", null);
     }
     setTimeout(_delayedPaneLoad, 0, this);
   },
@@ -1286,8 +1295,9 @@ var gApplicationsPane = {
 // XXXben - we need to compare this with the running instance executable
 //          just don't know how to do that via script...
 // XXXmano TBD: can probably add this to nsIShellService
+//@line 1374 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
    aExecutable.leafName != "firefox-bin";
-//@line 1364 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 1377 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
   },
 
   /**
@@ -1408,7 +1418,7 @@ var gApplicationsPane = {
     }
 
     // Create a menu item for selecting a local application.
-//@line 1491 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 1504 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
     {
       let menuItem = document.createElement("menuitem");
       menuItem.setAttribute("oncommand", "gApplicationsPane.chooseApp(event)");
@@ -1520,36 +1530,7 @@ var gApplicationsPane = {
    * Filter the list when the user enters a filter term into the filter field.
    */
   filter: function() {
-    if (this._filter.value == "") {
-      this.clearFilter();
-      return;
-    }
-
     this._rebuildView();
-
-    document.getElementById("clearFilter").disabled = false;
-  },
-
-  _filterTimeout: null,
-
-  onFilterInput: function() {
-    if (this._filterTimeout)
-      clearTimeout(this._filterTimeout);
-   
-    this._filterTimeout = setTimeout("gApplicationsPane.filter()", 500);
-  },
-
-  onFilterKeyPress: function(aEvent) {
-    if (aEvent.keyCode == KeyEvent.DOM_VK_ESCAPE)
-      this.clearFilter();
-  },
-  
-  clearFilter: function() {
-    this._filter.value = "";
-    this._rebuildView();
-
-    this._filter.focus();
-    document.getElementById("clearFilter").disabled = true;
   },
 
   focusFilterBox: function() {
@@ -1650,7 +1631,7 @@ var gApplicationsPane = {
 
     var handlerApp;
 
-//@line 1762 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 1746 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
     var fp = Cc["@mozilla.org/filepicker;1"].createInstance(Ci.nsIFilePicker);
     var winTitle = this._prefsBundle.getString("fpTitleChooseApp");
     fp.init(window, winTitle, Ci.nsIFilePicker.modeOpen);
@@ -1669,7 +1650,7 @@ var gApplicationsPane = {
       let handlerInfo = this._handledTypes[this._list.selectedItem.type];
       handlerInfo.addPossibleApplicationHandler(handlerApp);
     }
-//@line 1781 "/usr/obj/i386/firefox3-3.0.1p3/mozilla/browser/components/preferences/applications.js"
+//@line 1765 "/usr/obj/i386/firefox35-3.5/mozilla-1.9.1/browser/components/preferences/applications.js"
 
     // Rebuild the actions menu whether the user picked an app or canceled.
     // If they picked an app, we want to add the app to the menu and select it.
