@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/firefox3-3.0.1p3/mozilla/browser/base/content/safeMode.js"
+//@line 39 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/safeMode.js"
 
 function restartApp() {
   var appStartup = Components.classes["@mozilla.org/toolkit/app-startup;1"]
@@ -53,7 +53,15 @@ function disableAddons() {
   // Select the default theme
   var prefB = Components.classes["@mozilla.org/preferences-service;1"]
                         .getService(Components.interfaces.nsIPrefBranch);
-  prefB.clearUserPref("general.skins.selectedSkin");
+  if (prefB.prefHasUserValue("general.skins.selectedSkin"))
+    prefB.clearUserPref("general.skins.selectedSkin");
+
+  // Disable plugins
+  var phs = Components.classes["@mozilla.org/plugin/host;1"]
+                      .getService(Components.interfaces.nsIPluginHost);
+  var plugins = phs.getPluginTags({ });
+  for (i = 0; i < plugins.length; ++i)
+    plugins[i].disabled = true;
 }
 
 function restoreDefaultSearchEngines() {
