@@ -1,11 +1,12 @@
-//@line 39 "/usr/obj/ports/firefox3-3.0.1p3/mozilla/browser/base/content/utilityOverlay.js"
+//@line 39 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/utilityOverlay.js"
 
 /**
  * Communicator Shared Utility Library
  * for shared application glue for the Communicator suite of applications
  **/
 
-var goPrefWindow = 0;
+var TAB_DROP_TYPE = "application/x-moz-tabbrowser-tab";
+
 var gBidiUI = false;
 
 function getBrowserURL()
@@ -110,8 +111,11 @@ function openUILink( url, e, ignoreButton, ignoreAlt, allowKeywordFixup, postDat
  */
 function whereToOpenLink( e, ignoreButton, ignoreAlt )
 {
+  // This method must treat a null event like a left click without modifier keys (i.e.
+  // e = { shiftKey:false, ctrlKey:false, metaKey:false, altKey:false, button:0 })
+  // for compatibility purposes.
   if (!e)
-    e = { shiftKey:false, ctrlKey:false, metaKey:false, altKey:false, button:0 };
+    return "current";
 
   var shift = e.shiftKey;
   var ctrl =  e.ctrlKey;
@@ -124,9 +128,9 @@ function whereToOpenLink( e, ignoreButton, ignoreAlt )
 
   // Don't do anything special with right-mouse clicks.  They're probably clicks on context menu items.
 
-//@line 167 "/usr/obj/ports/firefox3-3.0.1p3/mozilla/browser/base/content/utilityOverlay.js"
+//@line 171 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/utilityOverlay.js"
   if (ctrl || (middle && middleUsesTabs)) {
-//@line 169 "/usr/obj/ports/firefox3-3.0.1p3/mozilla/browser/base/content/utilityOverlay.js"
+//@line 173 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/utilityOverlay.js"
     if (shift)
       return "tabshifted";
     else
@@ -220,8 +224,7 @@ function openUILinkIn( url, where, allowThirdPartyFixup, postData, referrerUrl )
 
 // Used as an onclick handler for UI elements with link-like behavior.
 // e.g. onclick="checkForMiddleClick(this, event);"
-function checkForMiddleClick(node, event)
-{
+function checkForMiddleClick(node, event) {
   // We should be using the disabled property here instead of the attribute,
   // but some elements that this function is used with don't support it (e.g.
   // menuitem).
@@ -229,12 +232,14 @@ function checkForMiddleClick(node, event)
     return; // Do nothing
 
   if (event.button == 1) {
-    /* Execute the node's oncommand.
+    /* Execute the node's oncommand or command.
      *
      * XXX: we should use node.oncommand(event) once bug 246720 is fixed.
      */
-    var fn = new Function("event", node.getAttribute("oncommand"));
-    fn.call(node, event);
+    var target = node.hasAttribute("oncommand") ? node :
+                 node.ownerDocument.getElementById(node.getAttribute("command"));
+    var fn = new Function("event", target.getAttribute("oncommand"));
+    fn.call(target, event);
 
     // If the middle-click was on part of a menu, close the menu.
     // (Menus close automatically with left-click but not with middle-click.)
@@ -310,6 +315,12 @@ function getShellService()
 }
 
 function isBidiEnabled() {
+  // first check the pref.
+  if (getBoolPref("bidi.browser.ui", false))
+    return true;
+
+  // if the pref isn't set, check for an RTL locale and force the pref to true
+  // if we find one.
   var rv = false;
 
   try {
@@ -324,21 +335,20 @@ function isBidiEnabled() {
       case "ur-":
       case "syr":
         rv = true;
+        var pref = Components.classes["@mozilla.org/preferences-service;1"]
+                             .getService(Components.interfaces.nsIPrefBranch);
+        pref.setBoolPref("bidi.browser.ui", true);
     }
   } catch (e) {}
 
-  // check the overriding pref
-  if (!rv)
-    rv = getBoolPref("bidi.browser.ui");
-
   return rv;
 }
 
 function openAboutDialog()
 {
-//@line 391 "/usr/obj/ports/firefox3-3.0.1p3/mozilla/browser/base/content/utilityOverlay.js"
+//@line 401 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/utilityOverlay.js"
   window.openDialog("chrome://browser/content/aboutDialog.xul", "About", "centerscreen,chrome,resizable=no");
-//@line 393 "/usr/obj/ports/firefox3-3.0.1p3/mozilla/browser/base/content/utilityOverlay.js"
+//@line 403 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/utilityOverlay.js"
 }
 
 function openPreferences(paneID, extraArgs)
@@ -375,40 +385,17 @@ function openAdvancedPreferences(tabID)
 
 /**
  * Opens the release notes page for this version of the application.
- * @param   event
- *          The DOM Event that caused this function to be called, used to
- *          determine where the release notes page should be displayed based
- *          on modifiers (e.g. Ctrl = new tab)
  */
-function openReleaseNotes(event)
+function openReleaseNotes()
 {
   var formatter = Components.classes["@mozilla.org/toolkit/URLFormatterService;1"]
                             .getService(Components.interfaces.nsIURLFormatter);
   var relnotesURL = formatter.formatURLPref("app.releaseNotesURL");
   
-  openUILink(relnotesURL, event, false, true);
+  openUILinkIn(relnotesURL, "tab");
 }
-  
-/**
- * Opens the update manager and checks for updates to the application.
- */
-function checkForUpdates()
-{
-  var um = 
-      Components.classes["@mozilla.org/updates/update-manager;1"].
-      getService(Components.interfaces.nsIUpdateManager);
-  var prompter = 
-      Components.classes["@mozilla.org/updates/update-prompt;1"].
-      createInstance(Components.interfaces.nsIUpdatePrompt);
 
-  // If there's an update ready to be applied, show the "Update Downloaded"
-  // UI instead and let the user know they have to restart the browser for
-  // the changes to be applied. 
-  if (um.activeUpdate && um.activeUpdate.state == "pending")
-    prompter.showUpdateDownloaded(um.activeUpdate);
-  else
-    prompter.checkForUpdates();
-}
+//@line 471 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/utilityOverlay.js"
 
 function buildHelpMenu()
 {
@@ -417,54 +404,10 @@ function buildHelpMenu()
   if (typeof safebrowsing != "undefined")
     safebrowsing.setReportPhishingMenu();
 
-  var updates = 
-      Components.classes["@mozilla.org/updates/update-service;1"].
-      getService(Components.interfaces.nsIApplicationUpdateService);
-  var um = 
-      Components.classes["@mozilla.org/updates/update-manager;1"].
-      getService(Components.interfaces.nsIUpdateManager);
-
-  // Disable the UI if the update enabled pref has been locked by the 
-  // administrator or if we cannot update for some other reason
-  var checkForUpdates = document.getElementById("checkForUpdates");
-  var canUpdate = updates.canUpdate;
-  checkForUpdates.setAttribute("disabled", !canUpdate);
-  if (!canUpdate)
-    return; 
-
-  var strings = document.getElementById("bundle_browser");
-  var activeUpdate = um.activeUpdate;
-  
-  // If there's an active update, substitute its name into the label
-  // we show for this item, otherwise display a generic label.
-  function getStringWithUpdateName(key) {
-    if (activeUpdate && activeUpdate.name)
-      return strings.getFormattedString(key, [activeUpdate.name]);
-    return strings.getString(key + "Fallback");
-  }
-  
-  // By default, show "Check for Updates..."
-  var key = "default";
-  if (activeUpdate) {
-    switch (activeUpdate.state) {
-    case "downloading":
-      // If we're downloading an update at present, show the text:
-      // "Downloading Firefox x.x..." otherwise we're paused, and show
-      // "Resume Downloading Firefox x.x..."
-      key = updates.isDownloading ? "downloading" : "resume";
-      break;
-    case "pending":
-      // If we're waiting for the user to restart, show: "Apply Downloaded
-      // Updates Now..."
-      key = "pending";
-      break;
-    }
-  }
-  checkForUpdates.label = getStringWithUpdateName("updatesItem_" + key);
-  if (um.activeUpdate && updates.isDownloading)
-    checkForUpdates.setAttribute("loading", "true");
-  else
-    checkForUpdates.removeAttribute("loading");
+//@line 529 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/utilityOverlay.js"
+  // Needed by safebrowsing for inserting its menuitem so just hide it
+  document.getElementById("updateSeparator").hidden = true;
+//@line 532 "/usr/obj/ports/firefox35-3.5/mozilla-1.9.1/browser/base/content/utilityOverlay.js"
 }
 
 function isElementVisible(aElement)
@@ -577,7 +520,7 @@ function openNewWindowWith(aURL, aDocument, aPostData, aAllowThirdPartyFixup,
 /**
  * isValidFeed: checks whether the given data represents a valid feed.
  *
- * @param  aData
+ * @param  aLink
  *         An object representing a feed with title, href and type.
  * @param  aPrincipal
  *         The principal of the document, used for security check.
@@ -585,40 +528,28 @@ function openNewWindowWith(aURL, aDocument, aPostData, aAllowThirdPartyFixup,
  *         Whether this is already a known feed or not, if true only a security
  *         check will be performed.
  */ 
-function isValidFeed(aData, aPrincipal, aIsFeed)
+function isValidFeed(aLink, aPrincipal, aIsFeed)
 {
-  if (!aData || !aPrincipal)
+  if (!aLink || !aPrincipal)
     return false;
 
+  var type = aLink.type.toLowerCase().replace(/^\s+|\s*(?:;.*)?$/g, "");
   if (!aIsFeed) {
-    var type = aData.type && aData.type.toLowerCase();
-    type = type.replace(/^\s+|\s*(?:;.*)?$/g, "");
-
     aIsFeed = (type == "application/rss+xml" ||
                type == "application/atom+xml");
-
-    if (!aIsFeed) {
-      // really slimy: general XML types with magic letters in the title
-      const titleRegex = /(^|\s)rss($|\s)/i;
-      aIsFeed = ((type == "text/xml" || type == "application/rdf+xml" ||
-                  type == "application/xml") && titleRegex.test(aData.title));
-    }
   }
 
   if (aIsFeed) {
     try {
-      urlSecurityCheck(aData.href, aPrincipal,
+      urlSecurityCheck(aLink.href, aPrincipal,
                        Components.interfaces.nsIScriptSecurityManager.DISALLOW_INHERIT_PRINCIPAL);
+      return type || "application/rss+xml";
     }
     catch(ex) {
-      aIsFeed = false;
     }
   }
 
-  if (type)
-    aData.type = type;
-
-  return aIsFeed;
+  return null;
 }
 
 // aCalledFromModal is optional
